;===============================================================================
;
;  Subroutine READDATA reads scientific data produced by GODUNOV in
;  HDF, HDF5 formats.
;
;-------------------------------------------------------------------------------
;
;  arguments:
;
;    file - file to read data from
;    var  - variable to be readed
;
function readdata, file, var, xcoord = x, ycoord = y, zcoord = z, time = t, _extra = extra

  if (n_elements(file) eq 0) then begin
    print, 'ERROR: No file to read from is specified!'
    print, '       Function should be called with two arguments!'
    print, '         ret = readdata(filename, variable)'
    return, -1
  endif

  if (n_elements(var) eq 0) then begin
    print, 'ERROR: No variable to read is specified!'
    print, '       Function should be called with two arguments!'
    print, '         ret = readdata(filename, variable)'
    return, -1
  endif

  if strmatch(file, '*[r,p,f,d]??????*.hdf') then begin
    ret = loadmhdhdf(file, var, xcoord = x, ycoord = y, zcoord = z, time = t, _extra = extra)
  endif else if strmatch(file, '*[r,p,f,d]??????_???.h5') then begin
    ret = loadmhdhdf5(file, var, xcoord = x, ycoord = y, zcoord = z, time = t, _extra = extra, /short)
  endif else if strmatch(file, '*[r,p,f,d]??????_?????.h5') then begin
    ret = loadmhdhdf5(file, var, xcoord = x, ycoord = y, zcoord = z, time = t, _extra = extra)
  endif else begin
    print, 'ERROR: Unknown origin of data!'
    print, '       Implement please!'
    return, -1
  endelse

  return, ret
end
